@@ -89,6 +89,11 @@ class PostExtractor:
             'source': None,
             'is_live': False,
             'factcheck': None,
+            'shared_post_id': None,
+            'shared_time': None,
+            'shared_user_id': None,
+            'shared_username': None,
+            'shared_post_url': None,
         }
 
     def extract_post(self) -> Post:
@@ -111,6 +116,7 @@ class PostExtractor:
             self.extract_video_id,
             self.extract_is_live,
             self.extract_factcheck,
+            self.extract_share_information,
         ]
 
         post = self.make_new_post()
@@ -119,26 +125,30 @@ class PostExtractor:
         # TODO: this is just used by `extract_reactions`, probably should not be acceded from self
         self.post = post
 
+        def log_warning(msg, *args):
+            post_id = self.post.get('post_id', 'unknown post')
+            logger.warning(f"[%s] {msg}", post_id, *args)
+
         for method in methods:
             try:
                 partial_post = method()
                 if partial_post is None:
-                    logger.warning("Extract method %s didn't return anything", method.__name__)
+                    log_warning("Extract method %s didn't return anything", method.__name__)
                     continue
 
                 post.update(partial_post)
             except Exception as ex:
-                logger.warning("Exception while running %s: %r", method.__name__, ex)
+                log_warning("Exception while running %s: %r", method.__name__, ex)
 
         if self.options.get('reactions'):
             try:
                 reactions = self.extract_reactions()
             except Exception as ex:
-                logger.warning("Exception while extracting reactions: %r", ex)
+                log_warning("Exception while extracting reactions: %r", ex)
                 reactions = {}
 
             if reactions is None:
-                logger.warning("Extract reactions didn't return anything")
+                log_warning("Extract reactions didn't return anything")
             else:
                 post.update(reactions)
 
@@ -165,6 +175,8 @@ class PostExtractor:
             if match:
                 url = utils.urljoin(FB_MOBILE_BASE_URL, match.groups()[0].replace("&amp;", "&"))
                 response = self.request(url)
+                # If .story_body_container is commented the find function won't work
+                response.html.html = response.html.html.replace('<!--', '').replace('-->', '')
                 element = response.html.find('.story_body_container', first=True)
 
         nodes = element.find('p, header, span[role=presentation]')
@@ -468,6 +480,22 @@ class PostExtractor:
             factcheck += text + "\n"
         return {'factcheck': factcheck}
 
+    def extract_share_information(self):
+        if not self.data_ft.get("original_content_id"):
+            return None
+        logger.debug("%s is a share of %s", self.post["post_id"], self.data_ft["original_content_id"])
+        # A shared post contains an <article> element within it's own <article> element, or a header element for a shared image
+        raw_post = self.element.find("article article, .story_body_container .story_body_container header", first=True)
+        # We can re-use the existing parsers, as a one level deep recursion
+        shared_post = PostExtractor(raw_post, self.options, self.request)
+        return {
+            'shared_post_id': self.data_ft["original_content_id"],
+            'shared_time': shared_post.extract_time().get("time"),
+            'shared_user_id': self.data_ft["original_content_owner_id"],
+            'shared_username': shared_post.extract_username().get("username"),
+            'shared_post_url': shared_post.extract_post_url().get("post_url")
+        }
+
     def parse_share_and_reactions(self, html: str):
         bad_jsons = self.shares_and_reactions_regex.findall(html)
         for bad_json in bad_jsons:
