@@ -26,11 +26,9 @@ class FacebookScraper:
         "AppleWebKit/537.36 (KHTML, like Gecko) "
         "Chrome/76.0.3809.87 Safari/537.36"
     )
-    cookie = 'locale=en_US;'
     default_headers = {
         'User-Agent': user_agent,
         'Accept-Language': 'en-US,en;q=0.5',
-        'cookie': cookie,
     }
 
     def __init__(self, session=None, requests_kwargs=None):
@@ -99,6 +97,12 @@ class FacebookScraper:
             warnings.warn("The options argument should be a dictionary.", stacklevel=3)
             options = {k: True for k in options}
 
+        if page_limit and page_limit <= 2:
+            warnings.warn(
+                "A low page limit (<=2) might return no results, try increasing the limit",
+                stacklevel=3,
+            )
+
         logger.debug("Starting to iterate pages")
         for i, page in zip(counter, iter_pages_fn()):
             logger.debug("Extracting posts from page %s", i)
